/*
 * Copyright (c) 1995 Andrew McRae.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef lint
static const char rcsid[] =
  "$FreeBSD: src/usr.sbin/pccard/pccardc/rdreg.c,v 1.9.2.3 1999/08/29 15:44:41 peter Exp $";
#endif /* not lint */

#include <err.h>
#include <fcntl.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/ioctl.h>

#include <pccard/cardinfo.h>

static int
dumpslot(sl)
	int     sl;
{
	char    name[64];
	int     fd;
	struct pcic_reg r;

	sprintf(name, CARD_DEVICE, sl);
	fd = open(name, O_RDONLY);
	if (fd < 0)
		return -1;
	printf("Registers for slot %d\n", sl);
	for (r.reg = 0; r.reg < 0x40; r.reg++) {
		if (ioctl(fd, PIOCGREG, &r)) {
			err(1, "ioctl (PIOCGREG)");
			break;
		}
		if ((r.reg % 16) == 0)
			printf("%02x:", r.reg);
		printf(" %02x", r.value);
		if ((r.reg % 16) == 15)
			printf("\n");
	}
	close(fd);
	return 0;
}

int
rdreg_main(argc, argv)
	int     argc;
	char   *argv[];
{
	int     node;

	if (argc != 2) {
		for (node = 0; node < 8; node++)
			dumpslot(node);
	} else {
		node = atoi(argv[1]);
		if (dumpslot(node))
			err(1, CARD_DEVICE, node);
	}
	return 0;
}
